@@ -15,13 +15,16 @@ class House(Thing):
     mirror = False
 
     def build(self):
+
         init_x = self.position.x
         init_y = self.position.y
         init_z = self.position.z
 
-        end_x = init_x + self.length-1
-        end_y = init_y + self.height-1
-        end_z = init_z + self.width-1
+        end_x = init_x + self.length - 1
+        if self.mirror:
+            end_x = init_x - (self.length - 1)
+        end_y = init_y + self.height - 1
+        end_z = init_z + self.width - 1
 
         self.server.setBlocks(
             init_x, init_y, init_z,
@@ -29,24 +32,22 @@ class House(Thing):
             self.block)
 
         # Fill the cube with air so it becomes a kind of house
+        init_x_empty = init_x + self.wall_width
+        end_x_empty = end_x - self.wall_width
+        if self.mirror:
+            init_x_empty = init_x - self.wall_width
+            end_x_empty = end_x + self.wall_width
         self.server.setBlocks(
-            init_x + self.wall_width, init_y, init_z + self.wall_width,
-            end_x - self.wall_width,
+            init_x_empty, init_y, init_z + self.wall_width,
+            end_x_empty,
             end_y - self.wall_width,
             end_z - self.wall_width,
             mcpi.block.AIR)
 
-        # Add a door
-        if not self.mirror:
-            self.server.setBlocks(
-                init_x, init_y, init_z + self.wall_width,
-                init_x + 1, init_y + self.door_size, init_z + self.door_size,
-                mcpi.block.AIR)
-        else:
-            self.server.setBlocks(
-                end_x, init_y, end_z - self.wall_width,
-                end_x - 1, init_y + self.door_size, end_z - self.door_size,
-                mcpi.block.AIR)
+        self.server.setBlocks(
+            init_x, init_y, init_z + self.wall_width,
+            init_x + 1, init_y + self.door_size, init_z + self.door_size,
+            mcpi.block.AIR)
 
         self._end_position = Vec3(end_x, end_y, end_z)
 
